@@ -22,6 +22,10 @@
  *
  */
 
+#define WAIT_FOR_SHUTDOWN_MS 100
+#define WAIT_FOR_OFFLINE_MS 100
+#define WAIT_FOR_OFFLINE_RETRIES 5
+
 #define G_LOG_DOMAIN "CallsSipOrigin"
 
 
@@ -61,6 +65,7 @@ enum {
   PROP_0,
   PROP_NAME,
   PROP_ID,
+  PROP_EMERGENCY_NUMBERS,
   PROP_ACC_HOST,
   PROP_ACC_USER,
   PROP_ACC_PASSWORD,
@@ -213,7 +218,8 @@ remove_calls (CallsSipOrigin *self,
 
   g_hash_table_remove_all (self->call_handles);
 
-  g_clear_pointer (&self->oper->call_handle, nua_handle_unref);
+  if (self->oper)
+    g_clear_pointer (&self->oper->call_handle, nua_handle_unref);
 }
 
 
@@ -1229,7 +1235,7 @@ deinit_sip_account (CallsSipOrigin *self)
   remove_calls (self, NULL);
 
   if (self->nua) {
-    g_debug ("Clearing any handles");
+    g_debug ("Clearing any handles for account '%s'", self->address);
     g_clear_pointer (&self->oper->register_handle, nua_handle_destroy);
     g_debug ("Requesting nua_shutdown ()");
     self->is_nua_shutdown = FALSE;
@@ -1237,7 +1243,7 @@ deinit_sip_account (CallsSipOrigin *self)
     nua_shutdown (self->nua);
     // need to wait for nua_r_shutdown event before calling nua_destroy ()
     while (!self->is_nua_shutdown)
-      su_root_step (self->ctx->root, 100);
+      su_root_step (self->ctx->root, WAIT_FOR_SHUTDOWN_MS);
 
     if (!self->is_shutdown_success) {
       g_warning ("nua_shutdown() timed out. Cannot proceed");
@@ -1247,8 +1253,7 @@ deinit_sip_account (CallsSipOrigin *self)
       return FALSE;
     }
     g_debug ("nua_shutdown() complete. Destroying nua handle");
-    nua_destroy (self->nua);
-    self->nua = NULL;
+    g_clear_pointer (&self->nua, nua_destroy);
   }
 
   g_clear_pointer (&self->own_ip, g_free);
@@ -1401,6 +1406,10 @@ calls_sip_origin_get_property (GObject    *object,
     g_value_set_string (value, self->id);
     break;
 
+  case PROP_EMERGENCY_NUMBERS:
+    g_value_set_boxed (value, NULL);
+    break;
+
   case PROP_ACC_HOST:
     g_value_set_string (value, self->host);
     break;
@@ -1501,6 +1510,21 @@ static void
 calls_sip_origin_dispose (GObject *object)
 {
   CallsSipOrigin *self = CALLS_SIP_ORIGIN (object);
+  gboolean su_step_timeout = FALSE;
+  guint i = 0;
+
+  if (!self->use_direct_connection && self->state == CALLS_ACCOUNT_STATE_ONLINE) {
+    go_online (CALLS_ACCOUNT (self), FALSE);
+
+    while (self->state != CALLS_ACCOUNT_STATE_OFFLINE && !su_step_timeout) {
+      su_root_step (self->ctx->root, WAIT_FOR_OFFLINE_MS);
+
+      if (i++ > WAIT_FOR_OFFLINE_RETRIES)
+        su_step_timeout = TRUE;
+    }
+  }
+
+  deinit_sip_account (self);
 
   g_clear_pointer (&self->id, g_free);
   g_clear_pointer (&self->own_ip, g_free);
@@ -1509,11 +1533,7 @@ calls_sip_origin_dispose (GObject *object)
   g_clear_pointer (&self->host, g_free);
   g_clear_pointer (&self->user, g_free);
   g_clear_pointer (&self->password, g_free);
-
-  if (!self->use_direct_connection && self->state == CALLS_ACCOUNT_STATE_ONLINE)
-    go_online (CALLS_ACCOUNT (self), FALSE);
-
-  deinit_sip_account (self);
+  g_clear_pointer (&self->address, g_free);
 
   G_OBJECT_CLASS (calls_sip_origin_parent_class)->dispose (object);
 }
@@ -1648,6 +1668,7 @@ calls_sip_origin_class_init (CallsSipOriginClass *klass)
   IMPLEMENTS (PROP_COUNTRY_CODE, "country-code");
   IMPLEMENTS (PROP_ACC_STATE, "account-state");
   IMPLEMENTS (PROP_ACC_ADDRESS, "address");
+  IMPLEMENTS (PROP_EMERGENCY_NUMBERS, "emergency-numbers");
 
 #undef IMPLEMENTS
 }
